@@ -3,10 +3,8 @@ multiprocessing.shared_memory.
 """
 
 from .shared_ndarray import (
-    VALID_SHARED_TYPES,
-    ShareableT,
-    SharedNDArray,
-    from_array,
-    from_shape,
+    VALID_SHARED_TYPES as VALID_SHARED_TYPES,
+    ShareableT as ShareableT,
+    SharedNDArray as SharedNDArray,
 )
 from .version import __version__
